==> certmanager-model-v1alpha3-6.2.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CertificateRequestListFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CertificateRequestListFluent<A extends CertificateRequestListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,CertificateRequest item);
  public A setToItems(Integer index,CertificateRequest item);
  public A addToItems(io.fabric8.certmanager.api.model.v1alpha3.CertificateRequest... items);
  public A addAllToItems(Collection<CertificateRequest> items);
  public A removeFromItems(io.fabric8.certmanager.api.model.v1alpha3.CertificateRequest... items);
  public A removeAllFromItems(Collection<CertificateRequest> items);
  public A removeMatchingFromItems(Predicate<CertificateRequestBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CertificateRequest> getItems();
  public List<CertificateRequest> buildItems();
  public CertificateRequest buildItem(Integer index);
  public CertificateRequest buildFirstItem();
  public CertificateRequest buildLastItem();
  public CertificateRequest buildMatchingItem(Predicate<CertificateRequestBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<CertificateRequestBuilder> predicate);
  public A withItems(List<CertificateRequest> items);
  public A withItems(io.fabric8.certmanager.api.model.v1alpha3.CertificateRequest... items);
  public Boolean hasItems();
  public CertificateRequestListFluent.ItemsNested<A> addNewItem();
  public CertificateRequestListFluent.ItemsNested<A> addNewItemLike(CertificateRequest item);
  public CertificateRequestListFluent.ItemsNested<A> setNewItemLike(Integer index,CertificateRequest item);
  public CertificateRequestListFluent.ItemsNested<A> editItem(Integer index);
  public CertificateRequestListFluent.ItemsNested<A> editFirstItem();
  public CertificateRequestListFluent.ItemsNested<A> editLastItem();
  public CertificateRequestListFluent.ItemsNested<A> editMatchingItem(Predicate<CertificateRequestBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,CertificateRequestFluent<CertificateRequestListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/CertificateRequestListFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CertificateRequestListFluent<A extends CertificateRequestListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,CertificateRequest item);
  public A setToItems(int index,CertificateRequest item);
  public A addToItems(io.fabric8.certmanager.api.model.v1alpha3.CertificateRequest... items);
  public A addAllToItems(Collection<CertificateRequest> items);
  public A removeFromItems(io.fabric8.certmanager.api.model.v1alpha3.CertificateRequest... items);
  public A removeAllFromItems(Collection<CertificateRequest> items);
  public A removeMatchingFromItems(Predicate<CertificateRequestBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CertificateRequest> getItems();
  public List<CertificateRequest> buildItems();
  public CertificateRequest buildItem(int index);
  public CertificateRequest buildFirstItem();
  public CertificateRequest buildLastItem();
  public CertificateRequest buildMatchingItem(Predicate<CertificateRequestBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<CertificateRequestBuilder> predicate);
  public A withItems(List<CertificateRequest> items);
  public A withItems(io.fabric8.certmanager.api.model.v1alpha3.CertificateRequest... items);
  public Boolean hasItems();
  public CertificateRequestListFluent.ItemsNested<A> addNewItem();
  public CertificateRequestListFluent.ItemsNested<A> addNewItemLike(CertificateRequest item);
  public CertificateRequestListFluent.ItemsNested<A> setNewItemLike(int index,CertificateRequest item);
  public CertificateRequestListFluent.ItemsNested<A> editItem(int index);
  public CertificateRequestListFluent.ItemsNested<A> editFirstItem();
  public CertificateRequestListFluent.ItemsNested<A> editLastItem();
  public CertificateRequestListFluent.ItemsNested<A> editMatchingItem(Predicate<CertificateRequestBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,CertificateRequestFluent<CertificateRequestListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
